Crate twozero48
twozero48
0.1.3
All Items
Crate Items
Structs
Enums
Crate
twozero48
Structs

Game
An object that models the board to play 2048 on and defines the rules for the game
Enums

Move
Used to depict user choice, an input to the
Game
API
Status
Used to depict the status in the
Game
API